allFromArgs property
bool
get
allFromArgs
Returns the all flag from the command line arguments
Implementation
bool get allFromArgs => argResults?['all'] as bool? ?? _cloneAllDefault;
Returns the all flag from the command line arguments
bool get allFromArgs => argResults?['all'] as bool? ?? _cloneAllDefault;